/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2007 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Application
    polyDualMesh

Description
    Calculate the dual of a polyMesh. Adheres to all the feature&patch edges

\*---------------------------------------------------------------------------*/

#include "argList.H"
#include "Time.H"
#include "polyDualMesh.H"
#include "mathematicalConstants.H"

using namespace Foam;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{
    argList::noParallel();
    argList::validArgs.append("feature angle[0-180]");

#   include "setRootCase.H"
#   include "createTime.H"
#   include "createPolyMesh.H"

    scalar featureAngle(readScalar(IStringStream(args.additionalArgs()[0])()));

    scalar minCos = Foam::cos(featureAngle * mathematicalConstant::pi/180.0);

    Info<< "Feature:" << featureAngle << endl
        << "minCos :" << minCos << endl
        << endl;

    polyDualMesh dualMesh(mesh, minCos);

    runTime++;

    Pout<< "Writing dualMesh to " << runTime.timeName() << endl;

    dualMesh.write();

    Info << "End\n" << endl;

    return 0;
}


// ************************************************************************* //
